## MetaWRAP

MetaWRAP aims to be an easy-to-use metagenomic wrapper suite that accomplishes the core tasks of metagenomic analysis.
Additionally, metaWRAP takes bin extraction and analysis to the next level. metaWRAP is meant to be a fast and simple approach before you delve deeper into parameterization of your analysis.
MetaWRAP can be applied to a variety of environments, including gut, water, and soil microbiomes (see metaWRAP paper for benchmarks).

### MetaWRAP binning module

The metaWRAP::Binning module is meant to be a convenient wrapper around three metagenomic binning software: MaxBin2, metaBAT2, and CONCOCT.
First the metagenomic assembly is indexed with bwa-index, and then paired end reads from any number of samples are aligned to it. The alignments are sorted and compressed with samtools, and library insert size statistics are also gathered at the same time (insert size average and standard deviation).
metaBAT2’s jgi_summarize_bam_contig_depths function is used to generate contig adundance table, and it is then converted into the correct format for each of the three binners to take as input.
After MaxBin2, metaBAT2, and CONCOCT finish binning the contigs with default settings, the final bins folders are created with formatted bin fasta files.
CheckM’s lineage_wf function is used to predict essential genes and estimate the completion and contamination of each bin.

### MetaWRAP bin refinement

The metaWRAP::Bin_refinement module utilizes a hybrid approach to take in two or three bin sets that were obtained with different software and produces a consolidated, improved bin set.
First, binning_refiner is used to create hybridized bins from every possible combination of sets.
If there were three bin sets: A, B, and C, then the following hybrid sets will be produced with binning_refiner: AB, BC, AC, and ABC.
CheckM is then run to evaluate the completion and contamination of the bins in each of the 7 bin sets (3 originals, 4 hybridized).
The bins sets are then iteratively compared to each other, and each pair is consolidated into an improved bin set.
To do this, the same bin is identified within the two bin sets based on a minimum of 80% overlap in genome length, and the better bin is determined based on which bin has the higher score.
The scoring function is S=Completion-5*Contamination.
After all bin sets are incorporated into the consolidated bin collection, a de-replication function removes any duplicate contigs.
If a contig is present in more than one bin, it is removed from all but the best bin (based on scoring function).
CheckM is then run on the final bin set and a final report file is generated showing the completion, contamination, and other statistics generated by CheckM for each bin.
Completion and contamination rank plots are also generated to evaluate the success of the Bin_refinement module, and compare its output to the quality of the original bins.


---

MetaWRAP's home page is [bxlab/metaWRAP](https://github.com/bxlab/metaWRAP).

This tool was wrapped by the Galaxy Australia team.
